@@ -6,16 +6,16 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0703';
+our $VERSION = '0.0704';
 
 use Algorithm::Combinatorics qw( combinations );
 use Math::Factor::XS qw( prime_factors );
-use Music::Chord::Namer qw( chordname );
 use MIDI::Pitch qw( name2freq );
-use Number::Fraction ();
-use Music::Scales qw(get_scale_notes);
-use Music::Intervals::Ratios;
 use Moo;
+use Music::Chord::Namer qw( chordname );
+use Music::Intervals::Ratios;
+use Music::Scales qw( get_scale_notes );
+use Number::Fraction ();
 use strictures 2;
 use namespace::clean;
 
@@ -27,7 +27,7 @@ has notes => (
 );
 sub _build_notes {
     my $self = shift;
-    return [ get_scale_notes( $self->tonic ) ];
+    return [ get_scale_notes( $self->_tonic ) ];
 }
 
 
@@ -36,42 +36,22 @@ has size => ( is => 'ro', default => sub { 3 } );
 
 has rootless => ( is => 'ro', default => sub { 0 } );
 
+has _octave => ( is => 'ro', default => sub { 4 } );
+has _concert => ( is => 'ro', default => sub { 440 } );
+has _tonic => ( is => 'ro', default => sub { 'C' } );
+has _semitones => ( is => 'ro', default => sub { 12 } );
 
-has octave => ( is => 'ro', default => sub { 4 } );
-
-
-has concert => ( is => 'ro', default => sub { 440 } );
-
-
-has tonic => ( is => 'ro', default => sub { 'C' } );
-
-
-has semitones => ( is => 'ro', default => sub { 12 } );
-
-
-has temper => (
+has _temper => (
     is      => 'ro',
     lazy    => 1,
     builder => 1,
 );
-sub _build_temper {
+sub _build__temper {
     my $self = shift;
-    $self->semitones * 100 / log(2);
+    $self->_semitones * 100 / log(2);
 }
 
-
-has midikey => ( is => 'ro', default => sub { 69 } );
-
-
-has scale => (
-    is      => 'ro',
-    lazy    => 1,
-    builder => 1,
-);
-sub _build_scale {
-    my $self = shift;
-    return [ map { eval "$Music::Intervals::Ratios::ratio->{$_}{ratio}" } @{ $self->notes } ];
-}
+has _midikey => ( is => 'ro', default => sub { 69 } );
 
 has _tonic_frequency => (
     is      => 'ro',
@@ -80,7 +60,7 @@ has _tonic_frequency => (
 );
 sub _build__tonic_frequency {
     my $self = shift;
-    return $self->concert * (2 ** (1 / $self->semitones)) ** (-9); # XXX Hardcoding: 9th key above middle-C
+    return $self->_concert * (2 ** (1 / $self->_semitones)) ** (-9); # XXX Hardcoding: 9th key above middle-C
 }
 
 has _note_index => (
@@ -154,7 +134,7 @@ sub integer_notation {
     while (my $c = $iter->next) {
         $integer_notation->{"@$c integer_notation"} = {
             map { $_ => sprintf '%.0f',
-                $self->midikey + $self->semitones * log( ($self->_tonic_frequency * (eval $self->_ratio_index->{$_})) / $self->concert ) / log(2)
+                $self->_midikey + $self->_semitones * log( ($self->_tonic_frequency * (eval $self->_ratio_index->{$_})) / $self->_concert ) / log(2)
             } @$c
         };
     }
@@ -175,7 +155,7 @@ sub eq_tempered_cents {
 
         $eq_tempered_cents->{"@$c eq_tempered_cents"} = {
             map {
-                $_ => log( $dyads{$_}->{eq_tempered} ) * $self->temper
+                $_ => log( $dyads{$_}->{eq_tempered} ) * $self->_temper
             } keys %dyads
         };
     }
@@ -194,7 +174,7 @@ sub eq_tempered_frequencies {
     while (my $c = $iter->next) {
         $eq_tempered_frequencies->{"@$c eq_tempered_frequencies"} = {
             map {
-                $_ => name2freq( $_ . $self->octave ) || $self->concert * $self->_note_index->{$_}
+                $_ => name2freq( $_ . $self->_octave ) || $self->_concert * $self->_note_index->{$_}
             } @$c
         };
     }
@@ -236,7 +216,7 @@ sub natural_cents {
 
         $natural_cents->{"@$c natural_cents"} = {
             map {
-                $_ => log( eval $dyads{$_}->{natural} ) * $self->temper
+                $_ => log( eval $dyads{$_}->{natural} ) * $self->_temper
             } keys %dyads
         };
     }
@@ -334,9 +314,9 @@ sub dyads {
             natural => $str,
             # The value is either the known pitch ratio or ...
             eq_tempered =>
-              ( name2freq( $i->[1] . $self->octave ) || ( $self->concert * $self->_note_index->{ $i->[1] } ) )
+              ( name2freq( $i->[1] . $self->_octave ) || ( $self->_concert * $self->_note_index->{ $i->[1] } ) )
                 /
-              ( name2freq( $i->[0] . $self->octave ) || ( $self->concert * $self->_note_index->{ $i->[0] } ) ),
+              ( name2freq( $i->[0] . $self->_octave ) || ( $self->_concert * $self->_note_index->{ $i->[0] } ) ),
         };
     }
 
@@ -383,7 +363,7 @@ Music::Intervals - Breakdown of musical intervals
 
 =head1 VERSION
 
-version 0.0703
+version 0.0704
 
 =head1 SYNOPSIS
 
@@ -391,7 +371,7 @@ version 0.0703
 
   my $m = Music::Intervals->new(
     notes => [qw/C E G B/],
-    size  => 3, # Must be <= the notes
+    size  => 3, # Must be <= notes
   );
 
   # Then any of:
@@ -408,13 +388,13 @@ version 0.0703
   );
 
   # Find known intervals
-  $name  = $m->by_ratio($ratio);
-  $ratio = $m->by_name($interval_name);
+  my $name  = $m->by_ratio('6/5');
+  my $ratio = $m->by_name('Eb');
 
   perl -Ilib -MMusic::Intervals::Ratios -E'say $Music::Intervals::Ratios::ratio->{C}{name}'
   # unison, perfect prime, tonic
 
-  # Show all the 447 known intervals:
+  # Show all the 400+ known intervals:
   perl -MData::Dumper -MMusic::Intervals::Ratios -e'print Dumper $Music::Intervals::Ratios::ratio'
 
 =head1 DESCRIPTION
@@ -474,49 +454,6 @@ Show chord names with no root.
 
 Default: C<0>
 
-=head2 octave
-
-The octave to use in internal computations.
-
-Default: C<4>
-
-=head2 concert
-
-Concert pitch to use in internal computations.
-
-Default: C<440>
-
-=head2 tonic
-
-The root of the computations.
-
-Default: C<C>
-
-* Currently (and for the foreseeable future) this will remain the only value
-that produces sane results.
-
-=head2 semitones
-
-Number of notes in the scale, used in internal computations.
-
-Default: C<12>
-
-=head2 temper
-
-Physical distance between notes, used in internal computations.
-
-Default: C<semitones * 100 / log(2)>
-
-=head2 midikey
-
-Describe this...
-
-Default: C<69>
-
-=head2 scale
-
-Describe this...
-
 =head1 METHODS
 
 =head2 new
