@@ -1,5 +1,5 @@
 package Music::Intervals::Ratios;
-$Music::Intervals::Ratios::VERSION = '0.0703';
+$Music::Intervals::Ratios::VERSION = '0.0704';
 our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Musical ratios
@@ -431,7 +431,7 @@ our $ratio = {
     },
     a13t => {
         ratio => '28/27',
-        name => q|Archytas' 1/3-tone, inferior quarter-tone|,
+        name => q|septimal 1/3-tone, inferior quarter-tone|,
     },
     '29h' => {
         ratio => '29/16',
@@ -1821,7 +1821,7 @@ Music::Intervals::Ratios - Musical ratios
 
 =head1 VERSION
 
-version 0.0703
+version 0.0704
 
 =head1 AUTHOR
 
